@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe "bundle install with explicit source paths" do
-  it "fetches gems with a global path source", :bundler => "< 3" do
+  it "fetches gems with a global path source", bundler: "< 3" do
     build_lib "foo"
 
     install_gemfile <<-G
@@ -16,6 +16,7 @@ RSpec.describe "bundle install with explicit source paths" do
     build_lib "foo"
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       path "#{lib_path("foo-1.0")}" do
         gem 'foo'
       end
@@ -28,6 +29,7 @@ RSpec.describe "bundle install with explicit source paths" do
     build_lib "foo"
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem 'foo', :path => "#{lib_path("foo-1.0")}"
     G
 
@@ -40,6 +42,7 @@ RSpec.describe "bundle install with explicit source paths" do
     relative_path = lib_path("foo-1.0").relative_path_from(bundled_app)
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem 'foo', :path => "#{relative_path}"
     G
 
@@ -52,6 +55,7 @@ RSpec.describe "bundle install with explicit source paths" do
     relative_path = lib_path("foo-1.0").relative_path_from(Pathname.new("~").expand_path)
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem 'foo', :path => "~/#{relative_path}"
     G
 
@@ -65,7 +69,8 @@ RSpec.describe "bundle install with explicit source paths" do
     username = "some_unexisting_user"
     relative_path = lib_path("foo-1.0").relative_path_from(Pathname.new("/home/#{username}").expand_path)
 
-    install_gemfile <<-G, :raise_on_error => false
+    install_gemfile <<-G, raise_on_error: false
+      source "https://gem.repo1"
       gem 'foo', :path => "~#{username}/#{relative_path}"
     G
     expect(err).to match("There was an error while trying to use the path `~#{username}/#{relative_path}`.")
@@ -73,25 +78,30 @@ RSpec.describe "bundle install with explicit source paths" do
   end
 
   it "expands paths relative to Bundler.root" do
-    build_lib "foo", :path => bundled_app("foo-1.0")
+    build_lib "foo", path: bundled_app("foo-1.0")
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem 'foo', :path => "./foo-1.0"
     G
 
-    expect(the_bundle).to include_gems("foo 1.0", :dir => bundled_app("subdir").mkpath)
+    expect(the_bundle).to include_gems("foo 1.0", dir: bundled_app("subdir").mkpath)
   end
 
   it "sorts paths consistently on install and update when they start with ./" do
-    build_lib "demo", :path => lib_path("demo")
-    build_lib "aaa", :path => lib_path("demo/aaa")
+    build_lib "demo", path: lib_path("demo")
+    build_lib "aaa", path: lib_path("demo/aaa")
 
-    gemfile = <<-G
+    gemfile lib_path("demo/Gemfile"), <<-G
+      source "https://gem.repo1"
       gemspec
       gem "aaa", :path => "./aaa"
     G
 
-    File.open(lib_path("demo/Gemfile"), "w") {|f| f.puts gemfile }
+    checksums = checksums_section_when_enabled do |c|
+      c.no_checksum "aaa", "1.0"
+      c.no_checksum "demo", "1.0"
+    end
 
     lockfile = <<~L
       PATH
@@ -105,6 +115,7 @@ RSpec.describe "bundle install with explicit source paths" do
           aaa (1.0)
 
       GEM
+        remote: https://gem.repo1/
         specs:
 
       PLATFORMS
@@ -113,84 +124,151 @@ RSpec.describe "bundle install with explicit source paths" do
       DEPENDENCIES
         aaa!
         demo!
-
+      #{checksums}
       BUNDLED WITH
          #{Bundler::VERSION}
     L
 
-    bundle :install, :dir => lib_path("demo")
-    expect(lib_path("demo/Gemfile.lock")).to have_lockfile(lockfile)
-    bundle :update, :all => true, :dir => lib_path("demo")
-    expect(lib_path("demo/Gemfile.lock")).to have_lockfile(lockfile)
+    bundle :install, dir: lib_path("demo")
+    expect(lib_path("demo/Gemfile.lock")).to read_as(lockfile)
+    bundle :update, all: true, dir: lib_path("demo")
+    expect(lib_path("demo/Gemfile.lock")).to read_as(lockfile)
   end
 
   it "expands paths when comparing locked paths to Gemfile paths" do
-    build_lib "foo", :path => bundled_app("foo-1.0")
+    build_lib "foo", path: bundled_app("foo-1.0")
 
     install_gemfile <<-G
-      gem 'foo', :path => File.expand_path("../foo-1.0", __FILE__)
+      source "https://gem.repo1"
+      gem 'foo', :path => File.expand_path("foo-1.0", __dir__)
     G
 
-    bundle "config --local frozen true"
+    bundle "config set --local frozen true"
     bundle :install
   end
 
   it "installs dependencies from the path even if a newer gem is available elsewhere" do
-    skip "override is not winning" if Gem.win_platform?
+    system_gems "myrack-1.0.0"
 
-    system_gems "rack-1.0.0"
-
-    build_lib "rack", "1.0", :path => lib_path("nested/bar") do |s|
-      s.write "lib/rack.rb", "puts 'WIN OVERRIDE'"
+    build_lib "myrack", "1.0", path: lib_path("nested/bar") do |s|
+      s.write "lib/myrack.rb", "puts 'WIN OVERRIDE'"
     end
 
-    build_lib "foo", :path => lib_path("nested") do |s|
-      s.add_dependency "rack", "= 1.0"
+    build_lib "foo", path: lib_path("nested") do |s|
+      s.add_dependency "myrack", "= 1.0"
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
+      source "https://gem.repo1"
       gem "foo", :path => "#{lib_path("nested")}"
     G
 
-    run "require 'rack'"
+    run "require 'myrack'"
     expect(out).to eq("WIN OVERRIDE")
   end
 
   it "works" do
-    build_gem "foo", "1.0.0", :to_system => true do |s|
+    build_gem "foo", "1.0.0", to_system: true do |s|
       s.write "lib/foo.rb", "puts 'FAIL'"
     end
 
-    build_lib "omg", "1.0", :path => lib_path("omg") do |s|
+    build_lib "omg", "1.0", path: lib_path("omg") do |s|
       s.add_dependency "foo"
     end
 
-    build_lib "foo", "1.0.0", :path => lib_path("omg/foo")
+    build_lib "foo", "1.0.0", path: lib_path("omg/foo")
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem "omg", :path => "#{lib_path("omg")}"
     G
 
     expect(the_bundle).to include_gems "foo 1.0"
   end
 
-  it "works with only_update_to_newer_versions" do
-    build_lib "omg", "2.0", :path => lib_path("omg")
+  it "works when using prereleases of 0.0.0" do
+    build_lib "foo", "0.0.0.dev", path: lib_path("foo")
+
+    gemfile <<~G
+      source "https://gem.repo1"
+      gem "foo", :path => "#{lib_path("foo")}"
+    G
+
+    lockfile <<~L
+      PATH
+        remote: #{lib_path("foo")}
+        specs:
+          foo (0.0.0.dev)
+
+      GEM
+        remote: https://gem.repo1/
+        specs:
+
+      PLATFORMS
+        #{lockfile_platforms}
+
+      DEPENDENCIES
+        foo!
+
+      BUNDLED WITH
+        #{Bundler::VERSION}
+    L
+
+    bundle :install
+
+    expect(the_bundle).to include_gems "foo 0.0.0.dev"
+  end
+
+  it "works when using uppercase prereleases of 0.0.0" do
+    build_lib "foo", "0.0.0.SNAPSHOT", path: lib_path("foo")
+
+    gemfile <<~G
+      source "https://gem.repo1"
+      gem "foo", :path => "#{lib_path("foo")}"
+    G
+
+    lockfile <<~L
+      PATH
+        remote: #{lib_path("foo")}
+        specs:
+          foo (0.0.0.SNAPSHOT)
+
+      GEM
+        remote: https://gem.repo1/
+        specs:
+
+      PLATFORMS
+        #{lockfile_platforms}
+
+      DEPENDENCIES
+        foo!
+
+      BUNDLED WITH
+        #{Bundler::VERSION}
+    L
+
+    bundle :install
+
+    expect(the_bundle).to include_gems "foo 0.0.0.SNAPSHOT"
+  end
+
+  it "handles downgrades" do
+    build_lib "omg", "2.0", path: lib_path("omg")
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem "omg", :path => "#{lib_path("omg")}"
     G
 
-    build_lib "omg", "1.0", :path => lib_path("omg")
+    build_lib "omg", "1.0", path: lib_path("omg")
 
-    bundle :install, :env => { "BUNDLE_BUNDLE_ONLY_UPDATE_TO_NEWER_VERSIONS" => "true" }
+    bundle :install
 
     expect(the_bundle).to include_gems "omg 1.0"
   end
 
   it "prefers gemspecs closer to the path root" do
-    build_lib "premailer", "1.0.0", :path => lib_path("premailer") do |s|
+    build_lib "premailer", "1.0.0", path: lib_path("premailer") do |s|
       s.write "gemfiles/ruby187.gemspec", <<-G
         Gem::Specification.new do |s|
           s.name    = 'premailer'
@@ -202,6 +280,7 @@ RSpec.describe "bundle install with explicit source paths" do
     end
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem "premailer", :path => "#{lib_path("premailer")}"
     G
 
@@ -222,7 +301,8 @@ RSpec.describe "bundle install with explicit source paths" do
       G
     end
 
-    install_gemfile <<-G, :raise_on_error => false
+    install_gemfile <<-G, raise_on_error: false
+      source "https://gem.repo1"
       gem "foo", :path => "#{lib_path("foo-1.0")}"
     G
 
@@ -233,79 +313,134 @@ RSpec.describe "bundle install with explicit source paths" do
   end
 
   it "supports gemspec syntax" do
-    build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-      s.add_dependency "rack", "1.0"
+    build_lib "foo", "1.0", path: lib_path("foo") do |s|
+      s.add_dependency "myrack", "1.0"
     end
 
-    gemfile = <<-G
-      source "#{file_uri_for(gem_repo1)}"
+    gemfile lib_path("foo/Gemfile"), <<-G
+      source "https://gem.repo1"
       gemspec
     G
 
-    File.open(lib_path("foo/Gemfile"), "w") {|f| f.puts gemfile }
+    bundle "install", dir: lib_path("foo")
+    expect(the_bundle).to include_gems "foo 1.0", dir: lib_path("foo")
+    expect(the_bundle).to include_gems "myrack 1.0", dir: lib_path("foo")
+  end
 
-    bundle "install", :dir => lib_path("foo")
-    expect(the_bundle).to include_gems "foo 1.0", :dir => lib_path("foo")
-    expect(the_bundle).to include_gems "rack 1.0", :dir => lib_path("foo")
+  it "does not unlock dependencies of path sources" do
+    build_repo4 do
+      build_gem "graphql", "2.0.15"
+      build_gem "graphql", "2.0.16"
+    end
+
+    build_lib "foo", "0.1.0", path: lib_path("foo") do |s|
+      s.add_dependency "graphql", "~> 2.0"
+    end
+
+    gemfile_path = lib_path("foo/Gemfile")
+
+    gemfile gemfile_path, <<-G
+      source "https://gem.repo4"
+      gemspec
+    G
+
+    lockfile_path = lib_path("foo/Gemfile.lock")
+
+    checksums = checksums_section_when_enabled do |c|
+      c.no_checksum "foo", "0.1.0"
+      c.checksum gem_repo4, "graphql", "2.0.15"
+    end
+
+    original_lockfile = <<~L
+      PATH
+        remote: .
+        specs:
+          foo (0.1.0)
+            graphql (~> 2.0)
+
+      GEM
+        remote: https://gem.repo4/
+        specs:
+          graphql (2.0.15)
+
+      PLATFORMS
+        #{lockfile_platforms}
+
+      DEPENDENCIES
+        foo!
+      #{checksums}
+      BUNDLED WITH
+         #{Bundler::VERSION}
+    L
+
+    lockfile lockfile_path, original_lockfile
+
+    build_lib "foo", "0.1.1", path: lib_path("foo") do |s|
+      s.add_dependency "graphql", "~> 2.0"
+    end
+
+    bundle "install", dir: lib_path("foo")
+    expect(lockfile_path).to read_as(original_lockfile.gsub("foo (0.1.0)", "foo (0.1.1)"))
   end
 
   it "supports gemspec syntax with an alternative path" do
-    build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-      s.add_dependency "rack", "1.0"
+    build_lib "foo", "1.0", path: lib_path("foo") do |s|
+      s.add_dependency "myrack", "1.0"
     end
 
     install_gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
+      source "https://gem.repo1"
       gemspec :path => "#{lib_path("foo")}"
     G
 
     expect(the_bundle).to include_gems "foo 1.0"
-    expect(the_bundle).to include_gems "rack 1.0"
+    expect(the_bundle).to include_gems "myrack 1.0"
   end
 
   it "doesn't automatically unlock dependencies when using the gemspec syntax" do
-    build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-      s.add_dependency "rack", ">= 1.0"
+    build_lib "foo", "1.0", path: lib_path("foo") do |s|
+      s.add_dependency "myrack", ">= 1.0"
     end
 
-    install_gemfile lib_path("foo/Gemfile"), <<-G, :dir => lib_path("foo")
-      source "#{file_uri_for(gem_repo1)}"
+    install_gemfile lib_path("foo/Gemfile"), <<-G, dir: lib_path("foo")
+      source "https://gem.repo1"
       gemspec
     G
 
-    build_gem "rack", "1.0.1", :to_system => true
+    build_gem "myrack", "1.0.1", to_system: true
 
-    bundle "install", :dir => lib_path("foo")
+    bundle "install", dir: lib_path("foo")
 
-    expect(the_bundle).to include_gems "foo 1.0", :dir => lib_path("foo")
-    expect(the_bundle).to include_gems "rack 1.0", :dir => lib_path("foo")
+    expect(the_bundle).to include_gems "foo 1.0", dir: lib_path("foo")
+    expect(the_bundle).to include_gems "myrack 1.0", dir: lib_path("foo")
   end
 
   it "doesn't automatically unlock dependencies when using the gemspec syntax and the gem has development dependencies" do
-    build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-      s.add_dependency "rack", ">= 1.0"
+    build_lib "foo", "1.0", path: lib_path("foo") do |s|
+      s.add_dependency "myrack", ">= 1.0"
       s.add_development_dependency "activesupport"
     end
 
-    install_gemfile lib_path("foo/Gemfile"), <<-G, :dir => lib_path("foo")
-      source "#{file_uri_for(gem_repo1)}"
+    install_gemfile lib_path("foo/Gemfile"), <<-G, dir: lib_path("foo")
+      source "https://gem.repo1"
       gemspec
     G
 
-    build_gem "rack", "1.0.1", :to_system => true
+    build_gem "myrack", "1.0.1", to_system: true
 
-    bundle "install", :dir => lib_path("foo")
+    bundle "install", dir: lib_path("foo")
 
-    expect(the_bundle).to include_gems "foo 1.0", :dir => lib_path("foo")
-    expect(the_bundle).to include_gems "rack 1.0", :dir => lib_path("foo")
+    expect(the_bundle).to include_gems "foo 1.0", dir: lib_path("foo")
+    expect(the_bundle).to include_gems "myrack 1.0", dir: lib_path("foo")
   end
 
   it "raises if there are multiple gemspecs" do
-    build_lib "foo", "1.0", :path => lib_path("foo") do |s|
+    build_lib "foo", "1.0", path: lib_path("foo") do |s|
       s.write "bar.gemspec", build_spec("bar", "1.0").first.to_ruby
     end
 
-    install_gemfile <<-G, :raise_on_error => false
+    install_gemfile <<-G, raise_on_error: false
+      source "https://gem.repo1"
       gemspec :path => "#{lib_path("foo")}"
     G
 
@@ -314,11 +449,12 @@ RSpec.describe "bundle install with explicit source paths" do
   end
 
   it "allows :name to be specified to resolve ambiguity" do
-    build_lib "foo", "1.0", :path => lib_path("foo") do |s|
+    build_lib "foo", "1.0", path: lib_path("foo") do |s|
       s.write "bar.gemspec"
     end
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gemspec :path => "#{lib_path("foo")}", :name => "foo"
     G
 
@@ -330,11 +466,13 @@ RSpec.describe "bundle install with explicit source paths" do
       s.executables = "foobar"
     end
 
-    install_gemfile <<-G
+    install_gemfile <<-G, verbose: true
+      source "https://gem.repo1"
       path "#{lib_path("foo-1.0")}" do
         gem 'foo'
       end
     G
+    expect(out).to include("Using foo 1.0 from source at `#{lib_path("foo-1.0")}` and installing its executables")
     expect(the_bundle).to include_gems "foo 1.0"
 
     bundle "exec foobar"
@@ -347,6 +485,7 @@ RSpec.describe "bundle install with explicit source paths" do
     lib_path("foo-1.0").join("bin/performance").mkpath
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem 'foo', '1.0', :path => "#{lib_path("foo-1.0")}"
     G
     expect(err).to be_empty
@@ -356,6 +495,7 @@ RSpec.describe "bundle install with explicit source paths" do
     build_lib "foo"
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem 'foo', :path => "#{lib_path("foo-1.0")}"
     G
 
@@ -368,6 +508,7 @@ RSpec.describe "bundle install with explicit source paths" do
       build_lib "hi2u"
 
       install_gemfile <<-G
+        source "https://gem.repo1"
         path "#{lib_path}" do
           gem "omg"
           gem "hi2u"
@@ -379,13 +520,14 @@ RSpec.describe "bundle install with explicit source paths" do
   end
 
   it "keeps source pinning" do
-    build_lib "foo", "1.0", :path => lib_path("foo")
-    build_lib "omg", "1.0", :path => lib_path("omg")
-    build_lib "foo", "1.0", :path => lib_path("omg/foo") do |s|
+    build_lib "foo", "1.0", path: lib_path("foo")
+    build_lib "omg", "1.0", path: lib_path("omg")
+    build_lib "foo", "1.0", path: lib_path("omg/foo") do |s|
       s.write "lib/foo.rb", "puts 'FAIL'"
     end
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem "foo", :path => "#{lib_path("foo")}"
       gem "omg", :path => "#{lib_path("omg")}"
     G
@@ -394,9 +536,10 @@ RSpec.describe "bundle install with explicit source paths" do
   end
 
   it "works when the path does not have a gemspec" do
-    build_lib "foo", :gemspec => false
+    build_lib "foo", gemspec: false
 
     gemfile <<-G
+      source "https://gem.repo1"
       gem "foo", "1.0", :path => "#{lib_path("foo-1.0")}"
     G
 
@@ -412,12 +555,13 @@ RSpec.describe "bundle install with explicit source paths" do
         specs:
 
       GEM
-        remote: http://rubygems.org
+        remote: http://rubygems.org/
     L
 
     FileUtils.mkdir_p(bundled_app("vendor/bar"))
 
     install_gemfile <<-G
+      source "http://rubygems.org"
       gem "bar", "1.0.0", path: "vendor/bar", require: "bar/nyard"
     G
   end
@@ -425,34 +569,34 @@ RSpec.describe "bundle install with explicit source paths" do
   context "existing lockfile" do
     it "rubygems gems don't re-resolve without changes" do
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack-obama', '1.0'
+        source "https://gem.repo1"
+        gem 'myrack-obama', '1.0'
         gem 'net-ssh', '1.0'
       G
 
-      bundle :check, :env => { "DEBUG" => "1" }
+      bundle :check, env: { "DEBUG" => "1" }
       expect(out).to match(/using resolution from the lockfile/)
-      expect(the_bundle).to include_gems "rack-obama 1.0", "net-ssh 1.0"
+      expect(the_bundle).to include_gems "myrack-obama 1.0", "net-ssh 1.0"
     end
 
     it "source path gems w/deps don't re-resolve without changes" do
-      build_lib "rack-obama", "1.0", :path => lib_path("omg") do |s|
+      build_lib "myrack-obama", "1.0", path: lib_path("omg") do |s|
         s.add_dependency "yard"
       end
 
-      build_lib "net-ssh", "1.0", :path => lib_path("omg") do |s|
+      build_lib "net-ssh", "1.0", path: lib_path("omg") do |s|
         s.add_dependency "yard"
       end
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem 'rack-obama', :path => "#{lib_path("omg")}"
+        source "https://gem.repo1"
+        gem 'myrack-obama', :path => "#{lib_path("omg")}"
         gem 'net-ssh', :path => "#{lib_path("omg")}"
       G
 
-      bundle :check, :env => { "DEBUG" => "1" }
+      bundle :check, env: { "DEBUG" => "1" }
       expect(out).to match(/using resolution from the lockfile/)
-      expect(the_bundle).to include_gems "rack-obama 1.0", "net-ssh 1.0"
+      expect(the_bundle).to include_gems "myrack-obama 1.0", "net-ssh 1.0"
     end
   end
 
@@ -462,6 +606,7 @@ RSpec.describe "bundle install with explicit source paths" do
     end
 
     install_gemfile <<-G
+      source "https://gem.repo1"
       gem "foo", :path => "#{lib_path("foo-1.0")}"
     G
 
@@ -471,18 +616,19 @@ RSpec.describe "bundle install with explicit source paths" do
 
   describe "when the gem version in the path is updated" do
     before :each do
-      build_lib "foo", "1.0", :path => lib_path("foo") do |s|
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
         s.add_dependency "bar"
       end
-      build_lib "bar", "1.0", :path => lib_path("foo/bar")
+      build_lib "bar", "1.0", path: lib_path("foo/bar")
 
       install_gemfile <<-G
+        source "https://gem.repo1"
         gem "foo", :path => "#{lib_path("foo")}"
       G
     end
 
     it "unlocks all gems when the top level gem is updated" do
-      build_lib "foo", "2.0", :path => lib_path("foo") do |s|
+      build_lib "foo", "2.0", path: lib_path("foo") do |s|
         s.add_dependency "bar"
       end
 
@@ -492,7 +638,7 @@ RSpec.describe "bundle install with explicit source paths" do
     end
 
     it "unlocks all gems when a child dependency gem is updated" do
-      build_lib "bar", "2.0", :path => lib_path("foo/bar")
+      build_lib "bar", "2.0", path: lib_path("foo/bar")
 
       bundle "install"
 
@@ -502,104 +648,233 @@ RSpec.describe "bundle install with explicit source paths" do
 
   describe "when dependencies in the path are updated" do
     before :each do
-      build_lib "foo", "1.0", :path => lib_path("foo")
+      build_lib "foo", "1.0", path: lib_path("foo")
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "foo", :path => "#{lib_path("foo")}"
       G
     end
 
     it "gets dependencies that are updated in the path" do
-      build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-        s.add_dependency "rack"
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
+        s.add_dependency "myrack"
       end
 
       bundle "install"
 
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     it "keeps using the same version if it's compatible" do
-      build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-        s.add_dependency "rack", "0.9.1"
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
+        s.add_dependency "myrack", "0.9.1"
       end
 
       bundle "install"
 
-      expect(the_bundle).to include_gems "rack 0.9.1"
+      expect(the_bundle).to include_gems "myrack 0.9.1"
 
-      lockfile_should_be <<-G
+      checksums = checksums_section_when_enabled do |c|
+        c.no_checksum "foo", "1.0"
+        c.checksum gem_repo1, "myrack", "0.9.1"
+      end
+
+      expect(lockfile).to eq <<~G
         PATH
           remote: #{lib_path("foo")}
           specs:
             foo (1.0)
-              rack (= 0.9.1)
+              myrack (= 0.9.1)
 
         GEM
-          remote: #{file_uri_for(gem_repo1)}/
+          remote: https://gem.repo1/
           specs:
-            rack (0.9.1)
+            myrack (0.9.1)
 
         PLATFORMS
           #{lockfile_platforms}
 
         DEPENDENCIES
           foo!
-
+        #{checksums}
         BUNDLED WITH
            #{Bundler::VERSION}
       G
 
-      build_lib "foo", "1.0", :path => lib_path("foo") do |s|
-        s.add_dependency "rack"
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
+        s.add_dependency "myrack"
       end
 
       bundle "install"
 
-      lockfile_should_be <<-G
+      expect(lockfile).to eq <<~G
         PATH
           remote: #{lib_path("foo")}
           specs:
             foo (1.0)
-              rack
+              myrack
 
         GEM
-          remote: #{file_uri_for(gem_repo1)}/
+          remote: https://gem.repo1/
           specs:
-            rack (0.9.1)
+            myrack (0.9.1)
 
         PLATFORMS
           #{lockfile_platforms}
 
         DEPENDENCIES
           foo!
-
+        #{checksums}
         BUNDLED WITH
            #{Bundler::VERSION}
       G
 
-      expect(the_bundle).to include_gems "rack 0.9.1"
+      expect(the_bundle).to include_gems "myrack 0.9.1"
+    end
+
+    it "keeps using the same version even when another dependency is added" do
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
+        s.add_dependency "myrack", "0.9.1"
+      end
+
+      bundle "install"
+
+      expect(the_bundle).to include_gems "myrack 0.9.1"
+
+      checksums = checksums_section_when_enabled do |c|
+        c.no_checksum "foo", "1.0"
+        c.checksum gem_repo1, "myrack", "0.9.1"
+      end
+
+      expect(lockfile).to eq <<~G
+        PATH
+          remote: #{lib_path("foo")}
+          specs:
+            foo (1.0)
+              myrack (= 0.9.1)
+
+        GEM
+          remote: https://gem.repo1/
+          specs:
+            myrack (0.9.1)
+
+        PLATFORMS
+          #{lockfile_platforms}
+
+        DEPENDENCIES
+          foo!
+        #{checksums}
+        BUNDLED WITH
+           #{Bundler::VERSION}
+      G
+
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
+        s.add_dependency "myrack"
+        s.add_dependency "rake", rake_version
+      end
+
+      bundle "install"
+
+      checksums.checksum gem_repo1, "rake", rake_version
+
+      expect(lockfile).to eq <<~G
+        PATH
+          remote: #{lib_path("foo")}
+          specs:
+            foo (1.0)
+              myrack
+              rake (= #{rake_version})
+
+        GEM
+          remote: https://gem.repo1/
+          specs:
+            myrack (0.9.1)
+            rake (#{rake_version})
+
+        PLATFORMS
+          #{lockfile_platforms}
+
+        DEPENDENCIES
+          foo!
+        #{checksums}
+        BUNDLED WITH
+           #{Bundler::VERSION}
+      G
+
+      expect(the_bundle).to include_gems "myrack 0.9.1"
+    end
+
+    it "does not remove existing ruby platform" do
+      build_lib "foo", "1.0", path: lib_path("foo") do |s|
+        s.add_dependency "myrack", "0.9.1"
+      end
+
+      checksums = checksums_section_when_enabled do |c|
+        c.no_checksum "foo", "1.0"
+      end
+
+      lockfile <<~L
+        PATH
+          remote: #{lib_path("foo")}
+          specs:
+            foo (1.0)
+
+        PLATFORMS
+          #{lockfile_platforms("ruby")}
+
+        DEPENDENCIES
+          foo!
+        #{checksums}
+        BUNDLED WITH
+           #{Bundler::VERSION}
+      L
+
+      bundle "lock"
+
+      checksums.checksum gem_repo1, "myrack", "0.9.1"
+
+      expect(lockfile).to eq <<~G
+        PATH
+          remote: #{lib_path("foo")}
+          specs:
+            foo (1.0)
+              myrack (= 0.9.1)
+
+        GEM
+          remote: https://gem.repo1/
+          specs:
+            myrack (0.9.1)
+
+        PLATFORMS
+          #{lockfile_platforms("ruby")}
+
+        DEPENDENCIES
+          foo!
+        #{checksums}
+        BUNDLED WITH
+           #{Bundler::VERSION}
+      G
     end
   end
 
   describe "switching sources" do
     it "doesn't switch pinned git sources to rubygems when pinning the parent gem to a path source" do
-      build_gem "foo", "1.0", :to_system => true do |s|
+      build_gem "foo", "1.0", to_system: true do |s|
         s.write "lib/foo.rb", "raise 'fail'"
       end
-      build_lib "foo", "1.0", :path => lib_path("bar/foo")
-      build_git "bar", "1.0", :path => lib_path("bar") do |s|
+      build_lib "foo", "1.0", path: lib_path("bar/foo")
+      build_git "bar", "1.0", path: lib_path("bar") do |s|
         s.add_dependency "foo"
       end
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "bar", :git => "#{lib_path("bar")}"
       G
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "bar", :path => "#{lib_path("bar")}"
       G
 
@@ -607,23 +882,23 @@ RSpec.describe "bundle install with explicit source paths" do
     end
 
     it "switches the source when the gem existed in rubygems and the path was already being used for another gem" do
-      build_lib "foo", "1.0", :path => lib_path("foo")
-      build_gem "bar", "1.0", :to_bundle => true do |s|
+      build_lib "foo", "1.0", path: lib_path("foo")
+      build_gem "bar", "1.0", to_bundle: true do |s|
         s.write "lib/bar.rb", "raise 'fail'"
       end
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "bar"
         path "#{lib_path("foo")}" do
           gem "foo"
         end
       G
 
-      build_lib "bar", "1.0", :path => lib_path("foo/bar")
+      build_lib "bar", "1.0", path: lib_path("foo/bar")
 
       install_gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         path "#{lib_path("foo")}" do
           gem "foo"
           gem "bar"
@@ -636,21 +911,17 @@ RSpec.describe "bundle install with explicit source paths" do
 
   describe "when there are both a gemspec and remote gems" do
     it "doesn't query rubygems for local gemspec name" do
-      skip "platform issues" if Gem.win_platform?
-
-      build_lib "private_lib", "2.2", :path => lib_path("private_lib")
-      gemfile = <<-G
+      build_lib "private_lib", "2.2", path: lib_path("private_lib")
+      gemfile lib_path("private_lib/Gemfile"), <<-G
         source "http://localgemserver.test"
         gemspec
-        gem 'rack'
+        gem 'myrack'
       G
-      File.open(lib_path("private_lib/Gemfile"), "w") {|f| f.puts gemfile }
-
-      bundle :install, :env => { "DEBUG" => "1" }, :artifice => "endpoint", :dir => lib_path("private_lib")
-      expect(out).to match(%r{^HTTP GET http://localgemserver\.test/api/v1/dependencies\?gems=rack$})
+      bundle :install, env: { "DEBUG" => "1" }, artifice: "endpoint", dir: lib_path("private_lib")
+      expect(out).to match(%r{^HTTP GET http://localgemserver\.test/api/v1/dependencies\?gems=myrack$})
       expect(out).not_to match(/^HTTP GET.*private_lib/)
-      expect(the_bundle).to include_gems "private_lib 2.2", :dir => lib_path("private_lib")
-      expect(the_bundle).to include_gems "rack 1.0", :dir => lib_path("private_lib")
+      expect(the_bundle).to include_gems "private_lib 2.2", dir: lib_path("private_lib")
+      expect(the_bundle).to include_gems "myrack 1.0", dir: lib_path("private_lib")
     end
   end
 
@@ -658,6 +929,7 @@ RSpec.describe "bundle install with explicit source paths" do
     it "runs pre-install hooks" do
       build_git "foo"
       gemfile <<-G
+        source "https://gem.repo1"
         gem "foo", :git => "#{lib_path("foo-1.0")}"
       G
 
@@ -670,13 +942,14 @@ RSpec.describe "bundle install with explicit source paths" do
       end
 
       bundle :install,
-        :requires => [lib_path("install_hooks.rb")]
+        requires: [lib_path("install_hooks.rb")]
       expect(err_without_deprecations).to eq("Ran pre-install hook: foo-1.0")
     end
 
     it "runs post-install hooks" do
       build_git "foo"
       gemfile <<-G
+        source "https://gem.repo1"
         gem "foo", :git => "#{lib_path("foo-1.0")}"
       G
 
@@ -689,13 +962,14 @@ RSpec.describe "bundle install with explicit source paths" do
       end
 
       bundle :install,
-        :requires => [lib_path("install_hooks.rb")]
+        requires: [lib_path("install_hooks.rb")]
       expect(err_without_deprecations).to eq("Ran post-install hook: foo-1.0")
     end
 
     it "complains if the install hook fails" do
       build_git "foo"
       gemfile <<-G
+        source "https://gem.repo1"
         gem "foo", :git => "#{lib_path("foo-1.0")}"
       G
 
@@ -707,7 +981,7 @@ RSpec.describe "bundle install with explicit source paths" do
         H
       end
 
-      bundle :install, :requires => [lib_path("install_hooks.rb")], :raise_on_error => false
+      bundle :install, requires: [lib_path("install_hooks.rb")], raise_on_error: false
       expect(err).to include("failed for foo-1.0")
     end
 
@@ -726,6 +1000,7 @@ RSpec.describe "bundle install with explicit source paths" do
       end
 
       install_gemfile <<-G
+        source "https://gem.repo1"
         gem "foo", :path => "#{lib_path("foo-1.0")}"
         gem "bar", :path => "#{lib_path("bar-1.0")}"
       G
