@@ -394,7 +394,7 @@ RSpec.describe "bundle install with install-time dependencies" do
         end
       end
 
-      context "with a Gemfile and lock file that don't resolve under the current platform" do
+      context "with a Gemfile and lockfile that don't resolve under the current platform" do
         before do
           build_repo4 do
             build_gem "sorbet", "0.5.10554" do |s|
@@ -606,13 +606,13 @@ RSpec.describe "bundle install with install-time dependencies" do
             s.required_ruby_version = "> 9000"
           end
           build_gem "myrack", "1.2" do |s|
-            s.platform = x86_mingw32
+            s.platform = "x86-mingw32"
             s.required_ruby_version = "> 9000"
           end
           build_gem "myrack", "1.2"
         end
 
-        simulate_platform x86_mingw32 do
+        simulate_platform "x86-mingw32" do
           install_gemfile <<-G, artifice: "compact_index"
             ruby "#{Gem.ruby_version}"
             source "https://gem.repo4"
