@@ -3,27 +3,27 @@
 RSpec.describe "bundle install" do
   describe "with path configured" do
     before :each do
-      build_gem "rack", "1.0.0", :to_system => true do |s|
-        s.write "lib/rack.rb", "puts 'FAIL'"
+      build_gem "myrack", "1.0.0", to_system: true do |s|
+        s.write "lib/myrack.rb", "puts 'FAIL'"
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
     end
 
     it "does not use available system gems with `vendor/bundle" do
       bundle "config set --local path vendor/bundle"
       bundle :install
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     it "uses system gems with `path.system` configured with more priority than `path`" do
       bundle "config set --local path.system true"
       bundle "config set --global path vendor/bundle"
       bundle :install
-      run "require 'rack'", :raise_on_error => false
+      run "require 'myrack'", raise_on_error: false
       expect(out).to include("FAIL")
     end
 
@@ -32,7 +32,7 @@ RSpec.describe "bundle install" do
       dir.mkpath
 
       bundle "config set --local path #{dir.join("vendor/bundle")}"
-      bundle :install, :dir => dir
+      bundle :install, dir: dir
       expect(out).to include("installed into `./vendor/bundle`")
 
       dir.rmtree
@@ -44,40 +44,40 @@ RSpec.describe "bundle install" do
       expect(out).to include("gems are installed into `./vendor/bundle`")
     end
 
-    it "disallows --path vendor/bundle --system", :bundler => "< 3" do
-      bundle "install --path vendor/bundle --system", :raise_on_error => false
+    it "disallows --path vendor/bundle --system", bundler: "< 3" do
+      bundle "install --path vendor/bundle --system", raise_on_error: false
       expect(err).to include("Please choose only one option.")
       expect(exitstatus).to eq(15)
     end
 
-    it "remembers to disable system gems after the first time with bundle --path vendor/bundle", :bundler => "< 3" do
+    it "remembers to disable system gems after the first time with bundle --path vendor/bundle", bundler: "< 3" do
       bundle "install --path vendor/bundle"
-      FileUtils.rm_rf bundled_app("vendor")
+      FileUtils.rm_r bundled_app("vendor")
       bundle "install"
 
-      expect(vendored_gems("gems/rack-1.0.0")).to be_directory
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(vendored_gems("gems/myrack-1.0.0")).to be_directory
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     context "with path_relative_to_cwd set to true" do
       before { bundle "config set path_relative_to_cwd true" }
 
-      it "installs the bundle relatively to current working directory", :bundler => "< 3" do
-        bundle "install --gemfile='#{bundled_app}/Gemfile' --path vendor/bundle", :dir => bundled_app.parent
+      it "installs the bundle relatively to current working directory", bundler: "< 3" do
+        bundle "install --gemfile='#{bundled_app}/Gemfile' --path vendor/bundle", dir: bundled_app.parent
         expect(out).to include("installed into `./vendor/bundle`")
         expect(bundled_app("../vendor/bundle")).to be_directory
-        expect(the_bundle).to include_gems "rack 1.0.0"
+        expect(the_bundle).to include_gems "myrack 1.0.0"
       end
 
       it "installs the standalone bundle relative to the cwd" do
-        bundle :install, :gemfile => bundled_app_gemfile, :standalone => true, :dir => bundled_app.parent
+        bundle :install, gemfile: bundled_app_gemfile, standalone: true, dir: bundled_app.parent
         expect(out).to include("installed into `./bundled_app/bundle`")
         expect(bundled_app("bundle")).to be_directory
         expect(bundled_app("bundle/ruby")).to be_directory
 
         bundle "config unset path"
 
-        bundle :install, :gemfile => bundled_app_gemfile, :standalone => true, :dir => bundled_app("subdir").tap(&:mkpath)
+        bundle :install, gemfile: bundled_app_gemfile, standalone: true, dir: bundled_app("subdir").tap(&:mkpath)
         expect(out).to include("installed into `../bundle`")
         expect(bundled_app("bundle")).to be_directory
         expect(bundled_app("bundle/ruby")).to be_directory
@@ -87,13 +87,13 @@ RSpec.describe "bundle install" do
 
   describe "when BUNDLE_PATH or the global path config is set" do
     before :each do
-      build_lib "rack", "1.0.0", :to_system => true do |s|
-        s.write "lib/rack.rb", "raise 'FAIL'"
+      build_lib "myrack", "1.0.0", to_system: true do |s|
+        s.write "lib/myrack.rb", "raise 'FAIL'"
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
     end
 
@@ -112,9 +112,9 @@ RSpec.describe "bundle install" do
           bundle "config set --local path vendor/bundle"
           bundle :install
 
-          expect(vendored_gems("gems/rack-1.0.0")).to be_directory
+          expect(vendored_gems("gems/myrack-1.0.0")).to be_directory
           expect(bundled_app("vendor2")).not_to be_directory
-          expect(the_bundle).to include_gems "rack 1.0.0"
+          expect(the_bundle).to include_gems "myrack 1.0.0"
         end
 
         it "installs gems to ." do
@@ -123,9 +123,9 @@ RSpec.describe "bundle install" do
 
           bundle :install
 
-          paths_to_exist = %w[cache/rack-1.0.0.gem gems/rack-1.0.0 specifications/rack-1.0.0.gemspec].map {|path| bundled_app(Bundler.ruby_scope, path) }
+          paths_to_exist = %w[cache/myrack-1.0.0.gem gems/myrack-1.0.0 specifications/myrack-1.0.0.gemspec].map {|path| bundled_app(Bundler.ruby_scope, path) }
           expect(paths_to_exist).to all exist
-          expect(the_bundle).to include_gems "rack 1.0.0"
+          expect(the_bundle).to include_gems "myrack 1.0.0"
         end
 
         it "installs gems to the path" do
@@ -133,18 +133,18 @@ RSpec.describe "bundle install" do
 
           bundle :install
 
-          expect(bundled_app("vendor", Bundler.ruby_scope, "gems/rack-1.0.0")).to be_directory
-          expect(the_bundle).to include_gems "rack 1.0.0"
+          expect(bundled_app("vendor", Bundler.ruby_scope, "gems/myrack-1.0.0")).to be_directory
+          expect(the_bundle).to include_gems "myrack 1.0.0"
         end
 
         it "installs gems to the path relative to root when relative" do
           set_bundle_path(type, "vendor")
 
           FileUtils.mkdir_p bundled_app("lol")
-          bundle :install, :dir => bundled_app("lol")
+          bundle :install, dir: bundled_app("lol")
 
-          expect(bundled_app("vendor", Bundler.ruby_scope, "gems/rack-1.0.0")).to be_directory
-          expect(the_bundle).to include_gems "rack 1.0.0"
+          expect(bundled_app("vendor", Bundler.ruby_scope, "gems/myrack-1.0.0")).to be_directory
+          expect(the_bundle).to include_gems "myrack 1.0.0"
         end
       end
     end
@@ -154,35 +154,35 @@ RSpec.describe "bundle install" do
 
       bundle :install
 
-      expect(vendored_gems("gems/rack-1.0.0")).to be_directory
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(vendored_gems("gems/myrack-1.0.0")).to be_directory
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     it "sets BUNDLE_PATH as the first argument to bundle install" do
       bundle "config set --local path ./vendor/bundle"
       bundle :install
 
-      expect(vendored_gems("gems/rack-1.0.0")).to be_directory
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(vendored_gems("gems/myrack-1.0.0")).to be_directory
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     it "disables system gems when passing a path to install" do
       # This is so that vendored gems can be distributed to others
-      build_gem "rack", "1.1.0", :to_system => true
+      build_gem "myrack", "1.1.0", to_system: true
       bundle "config set --local path ./vendor/bundle"
       bundle :install
 
-      expect(vendored_gems("gems/rack-1.0.0")).to be_directory
-      expect(the_bundle).to include_gems "rack 1.0.0"
+      expect(vendored_gems("gems/myrack-1.0.0")).to be_directory
+      expect(the_bundle).to include_gems "myrack 1.0.0"
     end
 
     it "re-installs gems whose extensions have been deleted" do
-      build_lib "very_simple_binary", "1.0.0", :to_system => true do |s|
+      build_lib "very_simple_binary", "1.0.0", to_system: true do |s|
         s.write "lib/very_simple_binary.rb", "raise 'FAIL'"
       end
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "very_simple_binary"
       G
 
@@ -191,11 +191,11 @@ RSpec.describe "bundle install" do
 
       expect(vendored_gems("gems/very_simple_binary-1.0")).to be_directory
       expect(vendored_gems("extensions")).to be_directory
-      expect(the_bundle).to include_gems "very_simple_binary 1.0", :source => "remote1"
+      expect(the_bundle).to include_gems "very_simple_binary 1.0", source: "remote1"
 
       vendored_gems("extensions").rmtree
 
-      run "require 'very_simple_binary_c'", :raise_on_error => false
+      run "require 'very_simple_binary_c'", raise_on_error: false
       expect(err).to include("Bundler::GemNotFound")
 
       bundle "config set --local path ./vendor/bundle"
@@ -203,7 +203,7 @@ RSpec.describe "bundle install" do
 
       expect(vendored_gems("gems/very_simple_binary-1.0")).to be_directory
       expect(vendored_gems("extensions")).to be_directory
-      expect(the_bundle).to include_gems "very_simple_binary 1.0", :source => "remote1"
+      expect(the_bundle).to include_gems "very_simple_binary 1.0", source: "remote1"
     end
   end
 
@@ -214,12 +214,12 @@ RSpec.describe "bundle install" do
 
     it "reports the file exists" do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
-        gem "rack"
+        source "https://gem.repo1"
+        gem "myrack"
       G
 
       bundle "config set --local path bundle"
-      bundle :install, :raise_on_error => false
+      bundle :install, raise_on_error: false
       expect(err).to include("file already exists")
     end
   end
