@@ -53,7 +53,7 @@ class TestGemCommandsOpenCommand < Gem::TestCase
       end
     end
 
-    assert_match %r{Unable to find gem 'foo'}, @ui.output
+    assert_match(/Unable to find gem 'foo'/, @ui.output)
     assert_equal "", @ui.error
   end
 
@@ -66,7 +66,7 @@ class TestGemCommandsOpenCommand < Gem::TestCase
       end
     end
 
-    assert_match %r{Unable to find gem 'foo'}, @ui.output
+    assert_match(/Unable to find gem 'foo'/, @ui.output)
     assert_equal "", @ui.error
   end
 
@@ -95,7 +95,7 @@ class TestGemCommandsOpenCommand < Gem::TestCase
       end
     end
 
-    assert_match %r{'foo' is a default gem and can't be opened\.} , @ui.output
+    assert_match(/'foo' is a default gem and can't be opened\./, @ui.output)
     assert_equal "", @ui.error
   end
 end
