@@ -33,8 +33,8 @@ class TestGemCommandsWhichCommand < Gem::TestCase
     end
 
     assert_equal "", @ui.output
-    assert_match %r{Can.t find Ruby library file or shared library directory\n},
-                 @ui.error
+    assert_match(/Can.t find Ruby library file or shared library directory\n/,
+                 @ui.error)
   end
 
   def test_execute_one_missing
@@ -51,8 +51,8 @@ class TestGemCommandsWhichCommand < Gem::TestCase
     end
 
     assert_equal "#{@foo_bar.full_gem_path}/lib/foo_bar.rb\n", @ui.output
-    assert_match %r{Can.t find Ruby library file or shared library missinglib\n},
-                 @ui.error
+    assert_match(/Can.t find Ruby library file or shared library missinglib\n/,
+                 @ui.error)
   end
 
   def test_execute_missing
@@ -65,8 +65,8 @@ class TestGemCommandsWhichCommand < Gem::TestCase
     end
 
     assert_equal "", @ui.output
-    assert_match %r{Can.t find Ruby library file or shared library missinglib\n},
-                 @ui.error
+    assert_match(/Can.t find Ruby library file or shared library missinglib\n/,
+                 @ui.error)
   end
 
   def util_foo_bar
