@@ -33,7 +33,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
         f.write "a" * 10
       end
 
-      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.now),
+      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                          @io.string[0, 512])
     end
     assert_equal "aaaaaaaaaa#{"\0" * 502}", @io.string[512, 512]
@@ -54,7 +54,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
     Time.stub :now, Time.at(1_458_518_157) do
       @tar_writer.add_symlink "x", "y", 0o644
 
-      assert_headers_equal(tar_symlink_header("x", "", 0o644, Time.now, "y"),
+      assert_headers_equal(tar_symlink_header("x", "", 0o644, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc, "y"),
                          @io.string[0, 512])
     end
     assert_equal 512, @io.pos
@@ -71,7 +71,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
   end
 
   def test_add_file_digest
-    digest_algorithms = Digest::SHA1.new, Digest::SHA512.new
+    digest_algorithms = OpenSSL::Digest::SHA1.new, OpenSSL::Digest::SHA512.new
 
     Time.stub :now, Time.at(1_458_518_157) do
       digests = @tar_writer.add_file_digest "x", 0o644, digest_algorithms do |io|
@@ -86,7 +86,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
                    "e1cf14b0",
                    digests["SHA512"].hexdigest
 
-      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.now),
+      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                          @io.string[0, 512])
     end
     assert_equal "aaaaaaaaaa#{"\0" * 502}", @io.string[512, 512]
@@ -94,7 +94,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
   end
 
   def test_add_file_digest_multiple
-    digest_algorithms = [Digest::SHA1.new, Digest::SHA512.new]
+    digest_algorithms = [OpenSSL::Digest::SHA1.new, OpenSSL::Digest::SHA512.new]
 
     Time.stub :now, Time.at(1_458_518_157) do
       digests = @tar_writer.add_file_digest "x", 0o644, digest_algorithms do |io|
@@ -109,7 +109,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
                    "e1cf14b0",
                    digests["SHA512"].hexdigest
 
-      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.now),
+      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                            @io.string[0, 512])
     end
     assert_equal "aaaaaaaaaa#{"\0" * 502}", @io.string[512, 512]
@@ -126,7 +126,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
         io.write "a" * 10
       end
 
-      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.now),
+      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                            @io.string[0, 512])
 
       assert_equal "aaaaaaaaaa#{"\0" * 502}", @io.string[512, 512]
@@ -137,7 +137,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
       signature = signer.sign digest.digest
 
       assert_headers_equal(tar_file_header("x.sig", "", 0o444, signature.length,
-                                           Time.now),
+                                           Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                            @io.string[1024, 512])
       assert_equal "#{signature}#{"\0" * (512 - signature.length)}",
                    @io.string[1536, 512]
@@ -154,7 +154,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
         io.write "a" * 10
       end
 
-      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.now),
+      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                            @io.string[0, 512])
     end
     assert_equal "aaaaaaaaaa#{"\0" * 502}", @io.string[512, 512]
@@ -168,7 +168,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
         io.write "a" * 10
       end
 
-      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.now),
+      assert_headers_equal(tar_file_header("x", "", 0o644, 10, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                            @io.string[0, 512])
 
       assert_equal "aaaaaaaaaa#{"\0" * 502}", @io.string[512, 512]
@@ -192,7 +192,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
     Time.stub :now, Time.at(1_458_518_157) do
       @tar_writer.add_file_simple "x", 0, 100
 
-      assert_headers_equal tar_file_header("x", "", 0, 100, Time.now),
+      assert_headers_equal tar_file_header("x", "", 0, 100, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
         @io.string[0, 512]
     end
 
@@ -250,7 +250,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
     Time.stub :now, Time.at(1_458_518_157) do
       @tar_writer.mkdir "foo", 0o644
 
-      assert_headers_equal tar_dir_header("foo", "", 0o644, Time.now),
+      assert_headers_equal tar_dir_header("foo", "", 0o644, Time.at(Gem::DEFAULT_SOURCE_DATE_EPOCH).utc),
                            @io.string[0, 512]
 
       assert_equal 512, @io.pos
@@ -283,7 +283,7 @@ class TestGemPackageTarWriter < Gem::Package::TarTestCase
     ]
     names.each do |name|
       newname, prefix = @tar_writer.split_name(name)
-      assert(!(newname.empty?), "split_name() returned empty name")
+      assert(!newname.empty?, "split_name() returned empty name")
       assert(newname.bytesize <= 100, "split_name() returned name longer than 100 bytes: '#{newname}' for '#{name}'")
       assert(prefix.bytesize <= 155, "split_name() returned prefix longer than 155 bytes: '#{prefix}' for '#{name}'")
       newname = [prefix, newname].join("/") unless prefix.empty?
